pro gyrortplot
;+
;This IDL routine reads and plots output from the Fortran 77
;gyrosynchrotron code GYRORT.  The output is in the file output.txt.
;
;The second parameter in FltArr must equal the number of lines of output
;to be read.
;
;-

;CREATE ARRAY & READ DATA FILE
;
gyroarray = FltArr(11,431)
OpenR, lun, 'output.txt', /Get_LUN
ReadF, lun, gyroarray
Free_LUN, lun
THETAD = Reform(gyroarray(0,*))
RNU    = Reform(gyroarray(1,*))
TAUEX  = Reform(gyroarray(2,*))
TAUOR  = Reform(gyroarray(3,*))
RADIEX = Reform(gyroarray(4,*))
RADIOR = Reform(gyroarray(5,*))
FLUXEX = Reform(gyroarray(6,*))
FLUXOR = Reform(gyroarray(7,*))
TBRIEX = Reform(gyroarray(8,*))
TBRIOR = Reform(gyroarray(9,*))
RADPOL = Reform(gyroarray(10,*))
FLUXTOTAL = (FLUXEX + FLUXOR)
TBTOTAL = (TBRIEX + TBRIOR)/2.

;SET COLOR TABLE
;
;  This makes colors on a PC behave in a manner similar to a workstation.
;
Device, Get_Visual_Depth = thisDepth
IF thisDepth GT 8 THEN Device, Decomposed = 0

;  Load "Rainbow" color table and set color 255 to white.

LoadCT, 13
TVLCT, 255, 255, 255, 255

;CREATE PLOTS

Window,0,Title = 'Flux'
plot, RNU*1.0E-9, FLUXTOTAL,/XLog,/YLog, XTitle = 'Frequency (GHz)',$
  YTitle = 'Flux (SFU)', Title = 'Microwave Flux in Solar Flux Units', $
  XRange = [0.4, 20.], YRange = [1.E-3,2.0E+02], XStyle = 1, YStyle = 1
oplot, RNU*1.0E-9, FLUXEX, LineStyle = 2, color=112
oplot, RNU*1.0E-9, FLUXOR, LineStyle = 1, color=208

Window,1,Title = 'Brightness Temperature'
plot, RNU*1.0E-9, TBTOTAL,/XLog,/YLog, XTitle = 'Frequency (GHz)',$
  Title = 'Brightness Temperature', $
  YTitle = 'Brightness Temperature (K)', XCharSize=1.2, YCharSize=1.2, $
  XRange = [0.4, 20.], YRange = [1.E+03,2.0E+8], XStyle = 1, YStyle = 1
oplot, RNU*1.0E-9, TBRIEX, LineStyle = 2, color=112
oplot, RNU*1.0E-9, TBRIOR, LineStyle = 1, color=208

;Create and position Legend for Brightness Temperature graph
PlotS, [9.0, 10.3], [3.E+07,3.E+07], LineStyle=0, color=255
XYOutS, 10.4, 3.E+07, 'Total', Size = 1.3
PlotS, [9.0, 10.3], [2.E+07,2.E+07], LineStyle=2, color=112
XYOutS, 10.4, 2.E+07, 'X-Mode', Size = 1.3
PlotS, [9.0, 10.3], [1.4E+07,1.4E+07], LineStyle=1, color=208
XYOutS, 10.4, 1.4E+07, 'O-Mode', Size = 1.3

Window,2,Title = 'Polarization'
plot, RNU*1.0E-9, RADPOL, /XLog, XTitle = 'Frequency (GHz)',$
  YTitle = 'Fractional Polarization', Title = 'Polarization (O-Mode Positive)', $
  XRange = [0.4, 20.], YRange = [-1,1], XStyle = 1, YStyle = 1

Window,3,Title = 'Optical Depth'
plot, RNU*1.0E-9, TAUEX,/XLog,/YLog, XTitle = 'Frequency (GHz)',$
  YTitle = 'tau', $
  Title = 'X & O Mode Optical Depths', $
  XRange = [0.4, 20.], YRange = [1.E-8,2.0E+05], XStyle = 1, YStyle = 1
oplot, RNU*1.0E-9, TAUOR, LineStyle = 2

;Create and position Legend for Optical Depth graph
PlotS, [9.0, 10.3], [1.0E04,1.0E04], LineStyle=0
XYOutS, 10.4, 1.0E04, 'TAUx', Size = 1.3
PlotS, [9.0, 10.3], [1.5E03,1.5E03], LineStyle=2
XYOutS, 10.4, 1.5E03, 'TAUo', Size = 1.3

END
